#! /usr/bin/env python
#  -*- coding: utf-8 -*-
#
# Support module generated by PAGE version 4.17
# In conjunction with Tcl version 8.6
#    Sep 20, 2018 12:17:49 PM EDT  platform: Windows NT

import sys

try:
    from Tkinter import *
except ImportError:
    from tkinter import *

try:
    import ttk
    py3 = False
except ImportError:
    import tkinter.ttk as ttk
    py3 = True

def set_Tk_var():
    global KMeansB
    KMeansB = IntVar()
    global NFindrB
    NFindrB = IntVar()
    global MBKmeansB
    MBKmeansB = IntVar()
    global ATGPB
    ATGPB = IntVar()
    global FIPPIB
    FIPPIB = IntVar()
    global PPIB
    PPIB = IntVar()
    global LLMB
    LLMB = IntVar()
    global ALSB
    ALSB = IntVar()
    global nb_i
    nb_i = IntVar()
    global nb_c
    nb_c = IntVar()

def init(top, gui, *args, **kwargs):
    global w, top_level, root
    w = gui
    top_level = top
    root = top

def destroy_window():
    # Function which closes the window.
    global top_level
    top_level.destroy()
    top_level = None

if __name__ == '__main__':
    import GUI
    GUI.vp_start_gui()


